@@ -5,7 +5,7 @@ use warnings;
 use Scalar::Util qw/reftype blessed/;
 use MooX::ReturnModifiers qw/return_modifiers/;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use constant ro       => 'ro';
 use constant is_ro    => ( is => ro );
@@ -77,10 +77,10 @@ sub _clone {
 
 sub _deep_clone {
     my ($to_clone) = @_;
-    my $reftype = reftype($to_clone) // reftype(\$to_clone);
-    $reftype eq 'SCALAR' and return $to_clone;
-    $reftype eq 'HASH'   and return { map +( $_ => _clone( $to_clone->{$_} ) ), keys %$to_clone };
-    $reftype eq 'ARRAY'  and return [ map _clone($_), @$to_clone ];
+    my $rt = reftype($to_clone) // reftype(\$to_clone);
+    $rt eq 'SCALAR' and return $to_clone;
+    $rt eq 'HASH'   and return { map +( $_ => _clone( $to_clone->{$_} ) ), keys %$to_clone };
+    $rt eq 'ARRAY'  and return [ map _clone($_), @$to_clone ];
     return $to_clone;
 }
 
@@ -94,7 +94,7 @@ MooX::LazierAttributes - Lazier Attributes.
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =cut
 
